@@ -161,23 +161,30 @@ static bool getTerminalInfoByPidEnv(FFTerminalResult* result, const char* pidEnv
 
 static void getTerminalFromEnv(FFTerminalResult* result)
 {
-    if(
-        result->processName.length > 0 &&
-        !ffStrbufStartsWithS(&result->processName, "login") &&
-        !ffStrbufEqualS(&result->processName, "(login)") &&
+    if (result->processName.length > 0)
+    {
+        if (!ffStrbufStartsWithS(&result->processName, "login") &&
+            !ffStrbufEqualS(&result->processName, "(login)") &&
 
-        #ifdef __APPLE__
-        !ffStrbufEqualS(&result->processName, "launchd") &&
-        !ffStrbufEqualS(&result->processName, "stable") && //for WarpTerminal
-        #else
-        !ffStrbufEqualS(&result->processName, "systemd") &&
-        !ffStrbufEqualS(&result->processName, "init") &&
-        !ffStrbufEqualS(&result->processName, "(init)") &&
-        !ffStrbufEqualS(&result->processName, "SessionLeader") && // #750
-        #endif
+            #ifdef __APPLE__
+            !ffStrbufEqualS(&result->processName, "launchd") &&
+            !ffStrbufEqualS(&result->processName, "stable") && //for WarpTerminal
+            #else
+            !ffStrbufEqualS(&result->processName, "systemd") &&
+            !ffStrbufEqualS(&result->processName, "init") &&
+            !ffStrbufEqualS(&result->processName, "(init)") &&
+            !ffStrbufEqualS(&result->processName, "SessionLeader") && // #750
+            #endif
 
-        !ffStrbufEqualS(&result->processName, "0")
-    ) return;
+            !ffStrbufEqualS(&result->processName, "0")
+        ) return;
+
+        ffStrbufClear(&result->processName);
+        ffStrbufClear(&result->exe);
+        result->exeName = result->exe.chars;
+        ffStrbufClear(&result->exePath);
+        result->pid = result->ppid = 0;
+    }
 
     const char* term = NULL;
 
@@ -229,7 +236,7 @@ static void getTerminalFromEnv(FFTerminalResult* result)
     }
     #endif
 
-    #if defined(__linux__) || defined(__FreeBSD__)
+    #if defined(__linux__) || defined(__FreeBSD__) || defined(__NetBSD__)
     //Konsole
     else if(
         getenv("KONSOLE_VERSION") != NULL
@@ -322,7 +329,7 @@ static void setTerminalInfoDetails(FFTerminalResult* result)
     else if(ffStrbufEqualS(&result->processName, "com.termux"))
         ffStrbufInitStatic(&result->prettyName, "Termux");
 
-    #elif defined(__linux__) || defined(__FreeBSD__)
+    #elif defined(__linux__) || defined(__FreeBSD__) || defined(__NetBSD__)
 
     else if(ffStrbufStartsWithS(&result->processName, "gnome-terminal"))
         ffStrbufInitStatic(&result->prettyName, "GNOME Terminal");
