@@ -79,3 +79,14 @@ static inline bool ffCharIsDigit(char c)
 {
     return '0' <= c && c <= '9';
 }
+
+// Copies at most (dstBufSiz - 1) bytes from src to dst; dst is always null-terminated
+static inline char* ffStrCopy(char* __restrict__ dst, const char* __restrict__ src, size_t dstBufSiz)
+{
+    if (__builtin_expect(dst == NULL, false)) return dst;
+
+    size_t len = strnlen(src, dstBufSiz - 1);
+    memcpy(dst, src, len);
+    dst[len] = '\0';
+    return dst + len;
+}
